@@ -1,8 +1,8 @@
 """Top-level package for mapwidget."""
 
 __author__ = """Qiusheng Wu"""
-__email__ = 'giswqs@gmail.com'
-__version__ = '0.1.2'
+__email__ = "giswqs@gmail.com"
+__version__ = "0.2.0"
 
 
 from .leaflet import *
