@@ -16,6 +16,10 @@ await loadScript(
 );
 
 export function render(view) {
+    // Header
+    let center = view.model.get("center");
+    let altitude = view.model.get("altitude");
+
     let width = view.model.get("width");
     let height = view.model.get("height");
 
@@ -25,6 +29,7 @@ export function render(view) {
 
     Cesium.Ion.defaultAccessToken = view.model.get("token");
 
+    // Map content
     const viewer = new Cesium.Viewer(div, {
         terrainProvider: Cesium.createWorldTerrain(),
     });
@@ -34,12 +39,30 @@ export function render(view) {
     );
 
     viewer.camera.flyTo({
-        destination: Cesium.Cartesian3.fromDegrees(-122.4175, 37.655, 400),
+        destination: Cesium.Cartesian3.fromDegrees(
+            center[1],
+            center[0],
+            altitude
+        ),
         orientation: {
             heading: Cesium.Math.toRadians(0.0),
             pitch: Cesium.Math.toRadians(-15.0),
         },
     });
 
+    viewer.camera.moveEnd.addEventListener(function () {
+        var cameraPosition = viewer.camera.position;
+        var center =
+            Cesium.Ellipsoid.WGS84.cartesianToCartographic(cameraPosition);
+        var lon = Cesium.Math.toDegrees(center.longitude);
+        var lat = Cesium.Math.toDegrees(center.latitude);
+        var height = viewer.camera.positionCartographic.height;
+        var zoomLevel = 18 - Math.log2(height);
+        view.model.set("center", [lat, lon]);
+        view.model.set("zoom", zoomLevel);
+        view.model.save_changes();
+    });
+
+    // Footer
     view.el.appendChild(div);
 }
